aboutsummaryrefslogtreecommitdiff
path: root/lib/curlx.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/curlx.h')
-rw-r--r--lib/curlx.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/lib/curlx.h b/lib/curlx.h
index 9dc90a004..42c62958d 100644
--- a/lib/curlx.h
+++ b/lib/curlx.h
@@ -34,29 +34,29 @@
functions while they still are offered publicly. They will be made library-
private one day */
#include "strequal.h"
/* "strequal.h" provides the strequal protos */
#include "strtoofft.h"
/* "strtoofft.h" provides this function: curlx_strtoofft(), returns a
curl_off_t number from a given string.
*/
-#include "timeval.h"
+#include "curl_timeval.h"
/*
- "timeval.h" sets up a 'struct timeval' even for platforms that otherwise
- don't have one and has protos for these functions:
+ "curl_timeval.h" sets up a 'struct timeval' even for platforms that
+ otherwise don't have one and has protos for these functions:
curlx_tvnow()
curlx_tvdiff()
curlx_tvdiff_secs()
*/
#include "nonblock.h"
/* "nonblock.h" provides curlx_nonblock() */
#include "warnless.h"
/* "warnless.h" provides functions:
curlx_ultous()
curlx_ultouc()
@@ -34,29 +34,29 @@
functions while they still are offered publicly. They will be made library-
private one day */
-#include "strequal.h"
-/* "strequal.h" provides the strequal protos */
+#include "curl_strequal.h"
+/* "curl_strequal.h" provides the strequal protos */
-#include "strtoofft.h"
-/* "strtoofft.h" provides this function: curlx_strtoofft(), returns a
+#include "curl_strtoofft.h"
+/* "curl_strtoofft.h" provides this function: curlx_strtoofft(), returns a
curl_off_t number from a given string.
*/
@@ -34,29 +34,29 @@
curlx_tvdiff_secs()
*/
-#include "nonblock.h"
-/* "nonblock.h" provides curlx_nonblock() */
+#include "curl_nonblock.h"
+/* "curl_nonblock.h" provides curlx_nonblock() */
-#include "warnless.h"
-/* "warnless.h" provides functions:
+#include "curl_warnless.h"
+/* "curl_warnless.h" provides functions:
curlx_ultous()
curlx_ultouc()